==> v0.7.tar.gz: lazydocker/docs/keybindings/Keybindings_de.md <==
# Lazydocker Menü

## Projekt

<pre>
  <kbd>e</kbd>: bearbeite lazydocker Konfiguration
  <kbd>o</kbd>: öffne lazydocker Konfiguration
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>m</kbd>: zeige Protokolle
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Container

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>d</kbd>: entfernen
  <kbd>e</kbd>: Hide/Show stopped containers
  <kbd>s</kbd>: anhalten
  <kbd>r</kbd>: neustarten
  <kbd>a</kbd>: anbinden
  <kbd>m</kbd>: zeige Protokolle
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Dienste

<pre>
  <kbd>d</kbd>: entferne Container
  <kbd>s</kbd>: anhalten
  <kbd>r</kbd>: neustarten
  <kbd>a</kbd>: anbinden
  <kbd>m</kbd>: zeige Protokolle
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>R</kbd>: zeige Neustartoptionen
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Images

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>d</kbd>: entferne Image
  <kbd>b</kbd>: view bulk commands
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Volumen

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>d</kbd>: entferne Volumen
  <kbd>b</kbd>: view bulk commands
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Haupt

<pre>
  <kbd>esc</kbd>: zurück
</pre>

==> v0.7.2.tar.gz: lazydocker/docs/keybindings/Keybindings_de.md <==
# Lazydocker Menü

## Projekt

<pre>
  <kbd>e</kbd>: bearbeite lazydocker Konfiguration
  <kbd>o</kbd>: öffne lazydocker Konfiguration
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>m</kbd>: zeige Protokolle
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Container

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>d</kbd>: entfernen
  <kbd>e</kbd>: Hide/Show stopped containers
  <kbd>s</kbd>: anhalten
  <kbd>r</kbd>: neustarten
  <kbd>a</kbd>: anbinden
  <kbd>m</kbd>: zeige Protokolle
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Dienste

<pre>
  <kbd>d</kbd>: entferne Container
  <kbd>s</kbd>: anhalten
  <kbd>r</kbd>: neustarten
  <kbd>a</kbd>: anbinden
  <kbd>m</kbd>: zeige Protokolle
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>R</kbd>: zeige Neustartoptionen
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Images

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>d</kbd>: entferne Image
  <kbd>b</kbd>: view bulk commands
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Volumes

<pre>
  <kbd>[</kbd>: vorheriges Tab
  <kbd>]</kbd>: nächstes Tab
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>d</kbd>: entferne Volume
  <kbd>b</kbd>: view bulk commands
  <kbd>c</kbd>: führe vordefinierten benutzerdefinierten Befehl aus
  <kbd>enter</kbd>: fokussieren aufs Hauptpanel
</pre>

## Haupt

<pre>
  <kbd>esc</kbd>: zurück
</pre>
